@@ -2,5 +2,5 @@
 
 void main_prog(int argc, char *argv[]);
 void exit_nicely (void);
-void usage (void);
+void usage (const char *argv0);
 int is_file (const char *filename);
